@@ -16,8 +16,6 @@
 import json
 
 from oslo_config import cfg
-from oslo_log import log
-import six
 from swiftclient import client as swift_client
 from swiftclient import exceptions as swift_exceptions
 
@@ -28,57 +26,29 @@ from ironic_inspector import utils
 CONF = cfg.CONF
 
 
-LOG = log.getLogger('ironic_inspector.common.swift')
-
 SWIFT_GROUP = 'swift'
 SWIFT_OPTS = [
     cfg.IntOpt('max_retries',
                default=2,
-               help='Maximum number of times to retry a Swift request, '
-                    'before failing.'),
+               help=_('Maximum number of times to retry a Swift request, '
+                      'before failing.')),
     cfg.IntOpt('delete_after',
                default=0,
-               help='Number of seconds that the Swift object will last before '
-                    'being deleted. (set to 0 to never delete the object).'),
+               help=_('Number of seconds that the Swift object will last '
+                      'before being deleted. (set to 0 to never delete the '
+                      'object).')),
     cfg.StrOpt('container',
                default='ironic-inspector',
-               help='Default Swift container to use when creating objects.'),
-    cfg.StrOpt('os_auth_version',
-               default='2',
-               help='Keystone authentication API version',
-               deprecated_for_removal=True,
-               deprecated_reason='Use options presented by configured '
-                                 'keystone auth plugin.'),
-    cfg.StrOpt('os_auth_url',
-               default='',
-               help='Keystone authentication URL',
-               deprecated_for_removal=True,
-               deprecated_reason='Use options presented by configured '
-                                 'keystone auth plugin.'),
+               help=_('Default Swift container to use when creating '
+                      'objects.')),
     cfg.StrOpt('os_service_type',
                default='object-store',
-               help='Swift service type.'),
+               help=_('Swift service type.')),
     cfg.StrOpt('os_endpoint_type',
                default='internalURL',
-               help='Swift endpoint type.'),
+               help=_('Swift endpoint type.')),
     cfg.StrOpt('os_region',
-               help='Keystone region to get endpoint for.'),
-]
-
-# NOTE(pas-ha) these old options conflict with options exported by
-# most used keystone auth plugins. Need to register them manually
-# for the backward-compat case.
-LEGACY_OPTS = [
-    cfg.StrOpt('username',
-               default='',
-               help='User name for accessing Swift API.'),
-    cfg.StrOpt('password',
-               default='',
-               help='Password for accessing Swift API.',
-               secret=True),
-    cfg.StrOpt('tenant_name',
-               default='',
-               help='Tenant name for accessing Swift API.'),
+               help=_('Keystone region to get endpoint for.')),
 ]
 
 CONF.register_opts(SWIFT_OPTS, group=SWIFT_GROUP)
@@ -86,12 +56,6 @@ keystone.register_auth_opts(SWIFT_GROUP)
 
 OBJECT_NAME_PREFIX = 'inspector_data'
 SWIFT_SESSION = None
-LEGACY_MAP = {
-    'auth_url': 'os_auth_url',
-    'username': 'username',
-    'password': 'password',
-    'tenant_name': 'tenant_name',
-}
 
 
 def reset_swift_session():
@@ -113,33 +77,9 @@ class SwiftAPI(object):
         """
         global SWIFT_SESSION
         if not SWIFT_SESSION:
-            SWIFT_SESSION = keystone.get_session(
-                SWIFT_GROUP, legacy_mapping=LEGACY_MAP,
-                legacy_auth_opts=LEGACY_OPTS)
-        # TODO(pas-ha): swiftclient does not support keystone sessions ATM.
-        # Must be reworked when LP bug #1518938 is fixed.
-        swift_url = SWIFT_SESSION.get_endpoint(
-            service_type=CONF.swift.os_service_type,
-            endpoint_type=CONF.swift.os_endpoint_type,
-            region_name=CONF.swift.os_region
-        )
-        token = SWIFT_SESSION.get_token()
-        params = dict(retries=CONF.swift.max_retries,
-                      preauthurl=swift_url,
-                      preauthtoken=token)
-        # NOTE(pas-ha):session.verify is for HTTPS urls and can be
-        # - False (do not verify)
-        # - True (verify but try to locate system CA certificates)
-        # - Path (verify using specific CA certificate)
-        # This is normally handled inside the Session instance,
-        # but swiftclient still does not support sessions,
-        # so we need to reconstruct these options from Session here.
-        verify = SWIFT_SESSION.verify
-        params['insecure'] = not verify
-        if verify and isinstance(verify, six.string_types):
-            params['cacert'] = verify
+            SWIFT_SESSION = keystone.get_session(SWIFT_GROUP)
 
-        self.connection = swift_client.Connection(**params)
+        self.connection = swift_client.Connection(session=SWIFT_SESSION)
 
     def create_object(self, object, data, container=CONF.swift.container,
                       headers=None):
