@@ -21,7 +21,7 @@ MIN_VERSION_HEADER = 'X-OpenStack-Ironic-Inspector-API-Minimum-Version'
 MAX_VERSION_HEADER = 'X-OpenStack-Ironic-Inspector-API-Maximum-Version'
 VERSION_HEADER = 'X-OpenStack-Ironic-Inspector-API-Version'
 
-VALID_ADD_PORTS_VALUES = ('all', 'active', 'pxe')
+VALID_ADD_PORTS_VALUES = ('all', 'active', 'pxe', 'disabled')
 VALID_KEEP_PORTS_VALUES = ('all', 'present', 'added')
 VALID_STORE_DATA_VALUES = ('none', 'swift')
 
@@ -76,12 +76,6 @@ PROCESSING_OPTS = [
                 help=_('Whether to overwrite existing values in node '
                        'database. Disable this option to make '
                        'introspection a non-destructive operation.')),
-    cfg.BoolOpt('enable_setting_ipmi_credentials',
-                default=False,
-                help=_('Whether to enable setting IPMI credentials during '
-                       'introspection. This feature will be removed in the '
-                       'Pike release.'),
-                deprecated_for_removal=True),
     cfg.StrOpt('default_processing_hooks',
                default='ramdisk_error,root_disk_selection,scheduler,'
                        'validate_interfaces,capabilities,pci_devices',
@@ -125,11 +119,6 @@ PROCESSING_OPTS = [
                        'partitioning. Only has effect when used with the IPA '
                        'as a ramdisk, for older ramdisk local_gb is '
                        'calculated on the ramdisk side.')),
-    cfg.BoolOpt('log_bmc_address',
-                default=True,
-                help=_('Whether to log node BMC address with every message '
-                       'during processing.'),
-                deprecated_for_removal=True),
     cfg.StrOpt('ramdisk_logs_filename_format',
                default='{uuid}_{dt:%Y%m%d-%H%M%S.%f}.tar.gz',
                help=_('File name template for storing ramdisk logs. The '
@@ -161,10 +150,12 @@ SERVICE_OPTS = [
                help=_('Timeout after which introspection is considered '
                       'failed, set to 0 to disable.')),
     cfg.IntOpt('node_status_keep_time',
-               default=604800,
+               default=0,
                help=_('For how much time (in seconds) to keep status '
                       'information about nodes after introspection was '
-                      'finished for them. Default value is 1 week.')),
+                      'finished for them. Set to 0 (the default) '
+                      'to disable the timeout.'),
+               deprecated_for_removal=True),
     cfg.IntOpt('clean_up_period',
                default=60,
                help=_('Amount of time in seconds, after which repeat clean up '
@@ -184,12 +175,6 @@ SERVICE_OPTS = [
     cfg.IntOpt('introspection_delay',
                default=5,
                help=_('Delay (in seconds) between two introspections.')),
-    cfg.StrOpt('introspection_delay_drivers',
-               default='.*',
-               help=_('Only node with drivers matching this regular '
-                      'expression will be affected by introspection_delay '
-                      'setting.'),
-               deprecated_for_removal=True),
     cfg.ListOpt('ipmi_address_fields',
                 default=['ilo_address', 'drac_host', 'drac_address',
                          'cimc_address'],
@@ -203,10 +188,19 @@ SERVICE_OPTS = [
                help=_('Limit the number of elements an API list-call returns'))
 ]
 
+PXE_FILTER_OPTS = [
+    cfg.StrOpt('driver', default='noop',
+               help=_('PXE boot filter driver to use, such as iptables. '
+                      'This option has no effect yet.')),
+    cfg.IntOpt('sync_period', default=15, min=0,
+               help=_('Amount of time in seconds, after which repeat periodic '
+                      'update of the filter. This option has no effect yet.')),
+]
 
 cfg.CONF.register_opts(SERVICE_OPTS)
 cfg.CONF.register_opts(FIREWALL_OPTS, group='firewall')
 cfg.CONF.register_opts(PROCESSING_OPTS, group='processing')
+cfg.CONF.register_opts(PXE_FILTER_OPTS, 'pxe_filter')
 
 
 def list_opts():
@@ -214,6 +208,7 @@ def list_opts():
         ('', SERVICE_OPTS),
         ('firewall', FIREWALL_OPTS),
         ('processing', PROCESSING_OPTS),
+        ('pxe_filter', PXE_FILTER_OPTS),
     ]
 
 
