@@ -340,23 +340,27 @@ class NodeInfo(object):
 
         :param ports: List of ports with all their attributes
                       e.g  [{'mac': xx, 'ip': xx, 'client_id': None},
-                            {'mac': xx, 'ip': None, 'client_id': None}]
+                      {'mac': xx, 'ip': None, 'client_id': None}]
                       It also support the old style of list of macs.
-        A warning is issued if port already exists on a node.
+                      A warning is issued if port already exists on a node.
+
         :param ironic: Ironic client to use instead of self.ironic
         """
         existing_macs = []
         for port in ports:
             mac = port
             extra = {}
+            pxe_enabled = True
             if isinstance(port, dict):
                 mac = port['mac']
                 client_id = port.get('client_id')
                 if client_id:
                     extra = {'client-id': client_id}
+                pxe_enabled = port.get('pxe', True)
 
             if mac not in self.ports():
-                self._create_port(mac, ironic=ironic, extra=extra)
+                self._create_port(mac, ironic=ironic, extra=extra,
+                                  pxe_enabled=pxe_enabled)
             else:
                 existing_macs.append(mac)
 
@@ -373,15 +377,20 @@ class NodeInfo(object):
         """
         if self._ports is None:
             ironic = ironic or self.ironic
-            self._ports = {p.address: p for p in
-                           ironic.node.list_ports(self.uuid, limit=0)}
+            port_list = ironic.node.list_ports(self.uuid, limit=0, detail=True)
+            self._ports = {p.address: p for p in port_list}
         return self._ports
 
-    def _create_port(self, mac, ironic=None, extra=None):
+    def _create_port(self, mac, ironic=None, **kwargs):
         ironic = ironic or self.ironic
         try:
             port = ironic.port.create(
-                node_uuid=self.uuid, address=mac, extra=extra)
+                node_uuid=self.uuid, address=mac, **kwargs)
+            LOG.info('Port %(uuid)s was created successfully, MAC: %(mac)s,'
+                     'attributes: %(attrs)s',
+                     {'uuid': port.uuid, 'mac': port.address,
+                      'attrs': kwargs},
+                     node_info=self)
         except exceptions.Conflict:
             LOG.warning('Port %s already exists, skipping',
                         mac, node_info=self)
@@ -856,22 +865,23 @@ def clean_up():
 
     :return: list of timed out node UUID's
     """
-    status_keep_threshold = (timeutils.utcnow() - datetime.timedelta(
-                             seconds=CONF.node_status_keep_time))
+    if CONF.node_status_keep_time > 0:
+        status_keep_threshold = (timeutils.utcnow() - datetime.timedelta(
+                                 seconds=CONF.node_status_keep_time))
+        with db.ensure_transaction() as session:
+            db.model_query(db.Node, session=session).filter(
+                db.Node.finished_at.isnot(None),
+                db.Node.finished_at < status_keep_threshold).delete()
 
-    with db.ensure_transaction() as session:
-        db.model_query(db.Node, session=session).filter(
-            db.Node.finished_at.isnot(None),
-            db.Node.finished_at < status_keep_threshold).delete()
+    timeout = CONF.timeout
+    if timeout <= 0:
+        return []
+    threshold = timeutils.utcnow() - datetime.timedelta(seconds=timeout)
+    uuids = [row.uuid for row in
+             db.model_query(db.Node.uuid).filter(
+                 db.Node.started_at < threshold,
+                 db.Node.finished_at.is_(None)).all()]
 
-        timeout = CONF.timeout
-        if timeout <= 0:
-            return []
-        threshold = timeutils.utcnow() - datetime.timedelta(seconds=timeout)
-        uuids = [row.uuid for row in
-                 db.model_query(db.Node.uuid, session=session).filter(
-                     db.Node.started_at < threshold,
-                     db.Node.finished_at.is_(None)).all()]
     if not uuids:
         return []
 
@@ -881,6 +891,11 @@ def clean_up():
         try:
             if node_info.finished_at or node_info.started_at > threshold:
                 continue
+            if node_info.state != istate.States.waiting:
+                LOG.error('Something went wrong, timeout occurred '
+                          'while introspection in "%s" state',
+                          node_info.state,
+                          node_info=node_info)
             node_info.fsm_event(istate.Events.timeout)
             node_info.finished(error='Introspection timeout')
         finally:
