@@ -45,11 +45,11 @@ class BaseTest(test_base.BaseTestCase):
         super(BaseTest, self).setUp()
         if not self.IS_FUNCTIONAL:
             self.init_test_conf()
-        self.session = db.get_session()
-        engine = db.get_engine()
+        self.session = db.get_writer_session()
+        engine = self.session.get_bind()
         db.Base.metadata.create_all(engine)
         engine.connect()
-        self.addCleanup(db.get_engine().dispose)
+        self.addCleanup(engine.dispose)
         plugins_base._HOOKS_MGR = None
         node_cache._SEMAPHORES = lockutils.Semaphores()
         patch = mock.patch.object(i18n, '_', lambda s: s)
@@ -63,7 +63,7 @@ class BaseTest(test_base.BaseTestCase):
         log.register_options(CONF)
         self.cfg = self.useFixture(config_fixture.Config(CONF))
         self.cfg.set_default('connection', "sqlite:///", group='database')
-        self.cfg.set_default('slave_connection', False, group='database')
+        self.cfg.set_default('slave_connection', None, group='database')
         self.cfg.set_default('max_retries', 10, group='database')
 
     def assertPatchEqual(self, expected, actual):
@@ -101,9 +101,9 @@ class InventoryTest(BaseTest):
             'ff:00:00:00:00:00:02:00:00:02:c9:00:7c:fe:90:03:00:29:26:52')
         self.valid_interfaces = {
             self.pxe_iface_name: {'ip': self.ips[0], 'mac': self.macs[0],
-                                  'client_id': None},
+                                  'client_id': None, 'pxe': True},
             'ib0': {'ip': self.ips[2], 'mac': self.macs[2],
-                    'client_id': self.client_id}
+                    'client_id': self.client_id, 'pxe': False}
         }
         self.data = {
             'boot_interface': '01-' + self.pxe_mac.replace(':', '-'),
@@ -145,20 +145,18 @@ class InventoryTest(BaseTest):
         self.inventory = self.data['inventory']
         self.all_interfaces = {
             'eth1': {'mac': self.macs[0], 'ip': self.ips[0],
-                     'client_id': None},
-            'eth2': {'mac': self.inactive_mac, 'ip': None, 'client_id': None},
+                     'client_id': None, 'pxe': True},
+            'eth2': {'mac': self.inactive_mac, 'ip': None,
+                     'client_id': None, 'pxe': False},
             'eth3': {'mac': self.macs[1], 'ip': self.ips[1],
-                     'client_id': None},
+                     'client_id': None, 'pxe': False},
             'ib0': {'mac': self.macs[2], 'ip': self.ips[2],
-                    'client_id': self.client_id}
+                    'client_id': self.client_id, 'pxe': False}
         }
         self.active_interfaces = {
-            'eth1': {'mac': self.macs[0], 'ip': self.ips[0],
-                     'client_id': None},
-            'eth3': {'mac': self.macs[1], 'ip': self.ips[1],
-                     'client_id': None},
-            'ib0': {'mac': self.macs[2], 'ip': self.ips[2],
-                    'client_id': self.client_id}
+            name: data
+            for (name, data) in self.all_interfaces.items()
+            if data.get('ip')
         }
         self.pxe_interfaces = {
             self.pxe_iface_name: self.all_interfaces[self.pxe_iface_name]
