@@ -19,20 +19,22 @@ import copy
 import datetime
 import json
 import os
-import shutil
 import tempfile
 import time
 import unittest
 
+import fixtures
 import mock
 from oslo_config import cfg
 from oslo_config import fixture as config_fixture
 from oslo_utils import timeutils
+from oslo_utils import uuidutils
 import pytz
 import requests
 import six
 from six.moves import urllib
 
+from ironic_inspector.cmd import all as inspector_cmd
 from ironic_inspector.common import ironic as ir_utils
 from ironic_inspector.common import swift
 from ironic_inspector import db
@@ -42,6 +44,7 @@ from ironic_inspector import main
 from ironic_inspector import node_cache
 from ironic_inspector import rules
 from ironic_inspector.test import base
+from ironic_inspector.test.unit import test_rules
 
 
 CONF = """
@@ -52,8 +55,6 @@ os_password = password
 os_tenant_name = tenant
 [firewall]
 manage_firewall = False
-[processing]
-enable_setting_ipmi_credentials = True
 [DEFAULT]
 debug = True
 auth_strategy = noauth
@@ -111,8 +112,9 @@ class Base(base.NodeTest):
         super(Base, self).setUp()
         rules.delete_all()
 
-        self.cli = ir_utils.get_client()
-        self.cli.reset_mock()
+        self.cli_fixture = self.useFixture(
+            fixtures.MockPatchObject(ir_utils, 'get_client'))
+        self.cli = self.cli_fixture.mock.return_value
         self.cli.node.get.return_value = self.node
         self.cli.node.update.return_value = self.node
         self.cli.node.list.return_value = [self.node]
@@ -160,13 +162,8 @@ class Base(base.NodeTest):
                 raise AssertionError(msg)
         return res
 
-    def call_introspect(self, uuid, new_ipmi_username=None,
-                        new_ipmi_password=None, **kwargs):
+    def call_introspect(self, uuid, **kwargs):
         endpoint = '/v1/introspection/%s' % uuid
-        if new_ipmi_password:
-            endpoint += '?new_ipmi_password=%s' % new_ipmi_password
-            if new_ipmi_username:
-                endpoint += '&new_ipmi_username=%s' % new_ipmi_username
         return self.call('post', endpoint, **kwargs)
 
     def call_get_status(self, uuid, **kwargs):
@@ -202,18 +199,20 @@ class Base(base.NodeTest):
     def call_get_rule(self, uuid, **kwargs):
         return self.call('get', '/v1/rules/' + uuid, **kwargs).json()
 
-    def _fake_status(self, finished=mock.ANY, error=mock.ANY,
+    def _fake_status(self, finished=mock.ANY, state=mock.ANY, error=mock.ANY,
                      started_at=mock.ANY, finished_at=mock.ANY,
                      links=mock.ANY):
         return {'uuid': self.uuid, 'finished': finished, 'error': error,
-                'finished_at': finished_at, 'started_at': started_at,
+                'state': state, 'finished_at': finished_at,
+                'started_at': started_at,
                 'links': [{u'href': u'%s/v1/introspection/%s' % (self.ROOT_URL,
                                                                  self.uuid),
                            u'rel': u'self'}]}
 
-    def check_status(self, status, finished, error=None):
+    def check_status(self, status, finished, state, error=None):
         self.assertEqual(
             self._fake_status(finished=finished,
+                              state=state,
                               finished_at=finished and mock.ANY or None,
                               error=error),
             status
@@ -242,7 +241,7 @@ class Test(Base):
                                                               'reboot')
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=False)
+        self.check_status(status, finished=False, state=istate.States.waiting)
 
         res = self.call_continue(self.data)
         self.assertEqual({'uuid': self.uuid}, res)
@@ -251,25 +250,37 @@ class Test(Base):
         self.cli.node.update.assert_called_once_with(self.uuid, mock.ANY)
         self.assertCalledWithPatch(self.patch, self.cli.node.update)
         self.cli.port.create.assert_called_once_with(
-            node_uuid=self.uuid, address='11:22:33:44:55:66', extra={})
+            node_uuid=self.uuid, address='11:22:33:44:55:66', extra={},
+            pxe_enabled=True)
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=True)
+        self.check_status(status, finished=True, state=istate.States.finished)
+
+    def test_port_creation_update_and_deletion(self):
+        cfg.CONF.set_override('add_ports', 'active', 'processing')
+        cfg.CONF.set_override('keep_ports', 'added', 'processing')
+
+        uuid_to_delete = uuidutils.generate_uuid()
+        uuid_to_update = uuidutils.generate_uuid()
+        # Two ports already exist: one with incorrect pxe_enabled, the other
+        # should be deleted.
+        self.cli.node.list_ports.return_value = [
+            mock.Mock(address=self.macs[1], uuid=uuid_to_update,
+                      node_uuid=self.uuid, extra={}, pxe_enabled=True),
+            mock.Mock(address='foobar', uuid=uuid_to_delete,
+                      node_uuid=self.uuid, extra={}, pxe_enabled=True),
+        ]
+        # Two more ports are created, one with client_id. Make sure the
+        # returned object has the same properties as requested in create().
+        self.cli.port.create.side_effect = mock.Mock
 
-    def test_bmc_with_client_id(self):
-        self.pxe_mac = self.macs[2]
-        self.data['boot_interface'] = ('20-' + self.pxe_mac.replace(':', '-'))
-        self.pxe_iface_name = 'ib0'
-        self.pxe_interfaces = {
-            self.pxe_iface_name: self.all_interfaces[self.pxe_iface_name]
-        }
         self.call_introspect(self.uuid)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
         self.cli.node.set_power_state.assert_called_once_with(self.uuid,
                                                               'reboot')
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=False)
+        self.check_status(status, finished=False, state=istate.States.waiting)
 
         res = self.call_continue(self.data)
         self.assertEqual({'uuid': self.uuid}, res)
@@ -277,42 +288,20 @@ class Test(Base):
 
         self.cli.node.update.assert_called_once_with(self.uuid, mock.ANY)
         self.assertCalledWithPatch(self.patch, self.cli.node.update)
-        self.cli.port.create.assert_called_once_with(
-            node_uuid=self.uuid, address=self.macs[2],
-            extra={'client-id': self.client_id})
-
-        status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=True)
-
-    def test_setup_ipmi(self):
-        patch_credentials = [
-            {'op': 'add', 'path': '/driver_info/ipmi_username',
-             'value': 'admin'},
-            {'op': 'add', 'path': '/driver_info/ipmi_password',
-             'value': 'pwd'},
+        calls = [
+            mock.call(node_uuid=self.uuid, address=self.macs[0],
+                      extra={}, pxe_enabled=True),
+            mock.call(node_uuid=self.uuid, address=self.macs[2],
+                      extra={'client-id': self.client_id}, pxe_enabled=False),
         ]
-        self.node.provision_state = 'enroll'
-        self.call_introspect(self.uuid, new_ipmi_username='admin',
-                             new_ipmi_password='pwd')
-        eventlet.greenthread.sleep(DEFAULT_SLEEP)
-        self.assertFalse(self.cli.node.set_power_state.called)
+        self.cli.port.create.assert_has_calls(calls, any_order=True)
+        self.cli.port.delete.assert_called_once_with(uuid_to_delete)
+        self.cli.port.update.assert_called_once_with(
+            uuid_to_update,
+            [{'op': 'replace', 'path': '/pxe_enabled', 'value': False}])
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=False)
-
-        res = self.call_continue(self.data)
-        self.assertEqual('admin', res['ipmi_username'])
-        self.assertEqual('pwd', res['ipmi_password'])
-        self.assertTrue(res['ipmi_setup_credentials'])
-        eventlet.greenthread.sleep(DEFAULT_SLEEP)
-
-        self.assertCalledWithPatch(self.patch + patch_credentials,
-                                   self.cli.node.update)
-        self.cli.port.create.assert_called_once_with(
-            node_uuid=self.uuid, address='11:22:33:44:55:66', extra={})
-
-        status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=True)
+        self.check_status(status, finished=True, state=istate.States.finished)
 
     def test_introspection_statuses(self):
         self.call_introspect(self.uuid)
@@ -339,7 +328,7 @@ class Test(Base):
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=True)
+        self.check_status(status, finished=True, state=istate.States.finished)
 
         # fetch all statuses and db nodes to assert pagination
         statuses = self.call_get_statuses().get('introspection')
@@ -368,13 +357,21 @@ class Test(Base):
         res = self.call_list_rules()
         self.assertEqual([], res)
 
-        rule = {'conditions': [],
-                'actions': [{'action': 'fail', 'message': 'boom'}],
-                'description': 'Cool actions'}
+        rule = {
+            'conditions': [
+                {'op': 'eq', 'field': 'memory_mb', 'value': 1024},
+            ],
+            'actions': [{'action': 'fail', 'message': 'boom'}],
+            'description': 'Cool actions'
+        }
+
         res = self.call_add_rule(rule)
         self.assertTrue(res['uuid'])
         rule['uuid'] = res['uuid']
         rule['links'] = res['links']
+        rule['conditions'] = [
+            test_rules.BaseTest.condition_defaults(rule['conditions'][0]),
+        ]
         self.assertEqual(rule, res)
 
         res = self.call('get', rule['links'][0]['href']).json()
@@ -504,7 +501,7 @@ class Test(Base):
                                                               'reboot')
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=False)
+        self.check_status(status, finished=False, state=istate.States.waiting)
 
         res = self.call_continue(self.data)
         self.assertEqual({'uuid': self.uuid}, res)
@@ -512,10 +509,11 @@ class Test(Base):
 
         self.assertCalledWithPatch(self.patch_root_hints, self.cli.node.update)
         self.cli.port.create.assert_called_once_with(
-            node_uuid=self.uuid, address='11:22:33:44:55:66', extra={})
+            node_uuid=self.uuid, address='11:22:33:44:55:66', extra={},
+            pxe_enabled=True)
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=True)
+        self.check_status(status, finished=True, state=istate.States.finished)
 
     def test_abort_introspection(self):
         self.call_introspect(self.uuid)
@@ -523,7 +521,7 @@ class Test(Base):
         self.cli.node.set_power_state.assert_called_once_with(self.uuid,
                                                               'reboot')
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=False)
+        self.check_status(status, finished=False, state=istate.States.waiting)
 
         res = self.call_abort_introspect(self.uuid)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
@@ -562,7 +560,7 @@ class Test(Base):
 
         status = self.call_get_status(self.uuid)
         inspect_started_at = timeutils.parse_isotime(status['started_at'])
-        self.check_status(status, finished=True)
+        self.check_status(status, finished=True, state=istate.States.finished)
 
         res = self.call_reapply(self.uuid)
         self.assertEqual(202, res.status_code)
@@ -570,7 +568,7 @@ class Test(Base):
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=True)
+        self.check_status(status, finished=True, state=istate.States.finished)
 
         # checks the started_at updated in DB is correct
         reapply_started_at = timeutils.parse_isotime(status['started_at'])
@@ -609,52 +607,6 @@ class Test(Base):
         self.assertEqual(store_processing_call,
                          store_mock.call_args_list[-1])
 
-    # TODO(milan): remove the test case in favor of other tests once
-    # the introspection status endpoint exposes the state information
-    @mock.patch.object(swift, 'store_introspection_data', autospec=True)
-    @mock.patch.object(swift, 'get_introspection_data', autospec=True)
-    def test_state_transitions(self, get_mock, store_mock):
-        """Assert state transitions work as expected."""
-        cfg.CONF.set_override('store_data', 'swift', 'processing')
-
-        # ramdisk data copy
-        # please mind the data is changed during processing
-        ramdisk_data = json.dumps(copy.deepcopy(self.data))
-        get_mock.return_value = ramdisk_data
-
-        self.call_introspect(self.uuid)
-        reboot_call = mock.call(self.uuid, 'reboot')
-        self.cli.node.set_power_state.assert_has_calls([reboot_call])
-
-        eventlet.greenthread.sleep(DEFAULT_SLEEP)
-        row = self.db_row()
-        self.assertEqual(istate.States.waiting, row.state)
-
-        self.call_continue(self.data)
-        eventlet.greenthread.sleep(DEFAULT_SLEEP)
-
-        row = self.db_row()
-        self.assertEqual(istate.States.finished, row.state)
-        self.assertIsNone(row.error)
-        version_id = row.version_id
-
-        self.call_reapply(self.uuid)
-        eventlet.greenthread.sleep(DEFAULT_SLEEP)
-        row = self.db_row()
-        self.assertEqual(istate.States.finished, row.state)
-        self.assertIsNone(row.error)
-        # the finished state was visited from the reapplying state
-        self.assertNotEqual(version_id, row.version_id)
-
-        self.call_introspect(self.uuid)
-        eventlet.greenthread.sleep(DEFAULT_SLEEP)
-        row = self.db_row()
-        self.assertEqual(istate.States.waiting, row.state)
-        self.call_abort_introspect(self.uuid)
-        row = self.db_row()
-        self.assertEqual(istate.States.error, row.state)
-        self.assertEqual('Canceled by operator', row.error)
-
     @mock.patch.object(swift, 'store_introspection_data', autospec=True)
     @mock.patch.object(swift, 'get_introspection_data', autospec=True)
     def test_edge_state_transitions(self, get_mock, store_mock):
@@ -670,30 +622,26 @@ class Test(Base):
         self.call_introspect(self.uuid)
         self.call_introspect(self.uuid)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
-        # TODO(milan): switch to API once the introspection status
-        # endpoint exposes the state information
-        row = self.db_row()
-        self.assertEqual(istate.States.waiting, row.state)
+        status = self.call_get_status(self.uuid)
+        self.check_status(status, finished=False, state=istate.States.waiting)
 
         # an error -start-> starting state transition is possible
         self.call_abort_introspect(self.uuid)
         self.call_introspect(self.uuid)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
-        row = self.db_row()
-        self.assertEqual(istate.States.waiting, row.state)
+        status = self.call_get_status(self.uuid)
+        self.check_status(status, finished=False, state=istate.States.waiting)
 
         # double abort works
         self.call_abort_introspect(self.uuid)
-        row = self.db_row()
-        version_id = row.version_id
-        error = row.error
-        self.assertEqual(istate.States.error, row.state)
+        status = self.call_get_status(self.uuid)
+        error = status['error']
+        self.check_status(status, finished=True, state=istate.States.error,
+                          error=error)
         self.call_abort_introspect(self.uuid)
-        row = self.db_row()
-        self.assertEqual(istate.States.error, row.state)
-        # assert the error didn't change
-        self.assertEqual(error, row.error)
-        self.assertEqual(version_id, row.version_id)
+        status = self.call_get_status(self.uuid)
+        self.check_status(status, finished=True, state=istate.States.error,
+                          error=error)
 
         # preventing stale data race condition
         # waiting -> processing is a strict state transition
@@ -704,26 +652,24 @@ class Test(Base):
         with db.ensure_transaction() as session:
             row.save(session)
         self.call_continue(self.data, expect_error=400)
-        row = self.db_row()
-        self.assertEqual(istate.States.error, row.state)
-        self.assertIn('no defined transition', row.error)
-
+        status = self.call_get_status(self.uuid)
+        self.check_status(status, finished=True, state=istate.States.error,
+                          error=mock.ANY)
+        self.assertIn('no defined transition', status['error'])
         # multiple reapply calls
         self.call_introspect(self.uuid)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
         self.call_continue(self.data)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
         self.call_reapply(self.uuid)
-        row = self.db_row()
-        version_id = row.version_id
-        self.assertEqual(istate.States.finished, row.state)
-        self.assertIsNone(row.error)
+        status = self.call_get_status(self.uuid)
+        self.check_status(status, finished=True, state=istate.States.finished,
+                          error=None)
         self.call_reapply(self.uuid)
         # assert an finished -reapply-> reapplying -> finished state transition
-        row = self.db_row()
-        self.assertEqual(istate.States.finished, row.state)
-        self.assertIsNone(row.error)
-        self.assertNotEqual(version_id, row.version_id)
+        status = self.call_get_status(self.uuid)
+        self.check_status(status, finished=True, state=istate.States.finished,
+                          error=None)
 
     def test_without_root_disk(self):
         del self.data['root_disk']
@@ -737,7 +683,7 @@ class Test(Base):
                                                               'reboot')
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=False)
+        self.check_status(status, finished=False, state=istate.States.waiting)
 
         res = self.call_continue(self.data)
         self.assertEqual({'uuid': self.uuid}, res)
@@ -746,10 +692,11 @@ class Test(Base):
         self.cli.node.update.assert_called_once_with(self.uuid, mock.ANY)
         self.assertCalledWithPatch(self.patch, self.cli.node.update)
         self.cli.port.create.assert_called_once_with(
-            node_uuid=self.uuid, extra={}, address='11:22:33:44:55:66')
+            node_uuid=self.uuid, extra={}, address='11:22:33:44:55:66',
+            pxe_enabled=True)
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=True)
+        self.check_status(status, finished=True, state=istate.States.finished)
 
     @mock.patch.object(swift, 'store_introspection_data', autospec=True)
     @mock.patch.object(swift, 'get_introspection_data', autospec=True)
@@ -765,14 +712,14 @@ class Test(Base):
                                                               'reboot')
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=False)
+        self.check_status(status, finished=False, state=istate.States.waiting)
 
         res = self.call_continue(self.data)
         self.assertEqual({'uuid': self.uuid}, res)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
 
         status = self.call_get_status(self.uuid)
-        self.check_status(status, finished=True)
+        self.check_status(status, finished=True, state=istate.States.finished)
 
         # Verify that the lldp_processed data is written to swift
         # as expected by the lldp plugin
@@ -789,35 +736,30 @@ class Test(Base):
 
 @contextlib.contextmanager
 def mocked_server():
-    d = tempfile.mkdtemp()
-    try:
-        conf_file = get_test_conf_file()
-        with mock.patch.object(ir_utils, 'get_client'):
-            dbsync.main(args=['--config-file', conf_file, 'upgrade'])
+    conf_file = get_test_conf_file()
+    dbsync.main(args=['--config-file', conf_file, 'upgrade'])
 
-            cfg.CONF.reset()
-            cfg.CONF.unregister_opt(dbsync.command_opt)
+    cfg.CONF.reset()
+    cfg.CONF.unregister_opt(dbsync.command_opt)
 
-            eventlet.greenthread.spawn_n(main.main,
-                                         args=['--config-file', conf_file])
-            eventlet.greenthread.sleep(1)
-            # Wait for service to start up to 30 seconds
-            for i in range(10):
-                try:
-                    requests.get('http://127.0.0.1:5050/v1')
-                except requests.ConnectionError:
-                    if i == 9:
-                        raise
-                    print('Service did not start yet')
-                    eventlet.greenthread.sleep(3)
-                else:
-                    break
-            # start testing
-            yield
-            # Make sure all processes finished executing
-            eventlet.greenthread.sleep(1)
-    finally:
-        shutil.rmtree(d)
+    eventlet.greenthread.spawn_n(inspector_cmd.main,
+                                 args=['--config-file', conf_file])
+    eventlet.greenthread.sleep(1)
+    # Wait for service to start up to 30 seconds
+    for i in range(10):
+        try:
+            requests.get('http://127.0.0.1:5050/v1')
+        except requests.ConnectionError:
+            if i == 9:
+                raise
+            print('Service did not start yet')
+            eventlet.greenthread.sleep(3)
+        else:
+            break
+    # start testing
+    yield
+    # Make sure all processes finished executing
+    eventlet.greenthread.sleep(1)
 
 
 if __name__ == '__main__':
