@@ -13,8 +13,6 @@
 
 import os
 
-from oslo_config import cfg
-from tempest import config as tempest_config
 from tempest.test_discover import plugins
 
 from ironic_inspector.test.inspector_tempest_plugin import config
@@ -29,20 +27,15 @@ class InspectorTempestPlugin(plugins.TempestPlugin):
         return full_test_dir, base_path
 
     def register_opts(self, conf):
-        tempest_config.register_opt_group(
-            conf, config.service_available_group,
-            config.ServiceAvailableGroup)
-        tempest_config.register_opt_group(
-            conf, config.baremetal_introspection_group,
-            config.BaremetalIntrospectionGroup)
-        if os.path.exists('/tmp/ironic-inspector-grenade'):
-            # FIXME(dtantsur): pretend like Neutron does not exist due to
-            # random failures, see https://bugs.launchpad.net/bugs/1621791.
-            cfg.CONF.set_override('neutron', False, 'service_available')
+        conf.register_opt(config.service_option,
+                          group='service_available')
+        conf.register_group(config.baremetal_introspection_group)
+        conf.register_opts(config.BaremetalIntrospectionGroup,
+                           group="baremetal_introspection")
 
     def get_opt_lists(self):
         return [
             (config.baremetal_introspection_group.name,
              config.BaremetalIntrospectionGroup),
-            ('service_available', config.ServiceAvailableGroup)
+            ('service_available', [config.service_option])
         ]
