@@ -13,8 +13,6 @@
 
 import datetime
 import json
-import ssl
-import sys
 import unittest
 
 import mock
@@ -22,9 +20,8 @@ from oslo_utils import uuidutils
 
 from ironic_inspector.common import ironic as ir_utils
 from ironic_inspector import conf
-from ironic_inspector import db
-from ironic_inspector import firewall
 from ironic_inspector import introspect
+from ironic_inspector import introspection_state as istate
 from ironic_inspector import main
 from ironic_inspector import node_cache
 from ironic_inspector.plugins import base as plugins_base
@@ -58,38 +55,8 @@ class TestApiIntrospect(BaseAPITest):
         res = self.app.post('/v1/introspection/%s' % self.uuid)
         self.assertEqual(202, res.status_code)
         introspect_mock.assert_called_once_with(self.uuid,
-                                                new_ipmi_credentials=None,
                                                 token=None)
 
-    @mock.patch.object(introspect, 'introspect', autospec=True)
-    def test_introspect_set_ipmi_credentials(self, introspect_mock):
-        res = self.app.post('/v1/introspection/%s?new_ipmi_username=user&'
-                            'new_ipmi_password=password' % self.uuid)
-        self.assertEqual(202, res.status_code)
-        introspect_mock.assert_called_once_with(
-            self.uuid,
-            new_ipmi_credentials=('user', 'password'),
-            token=None)
-
-    @mock.patch.object(introspect, 'introspect', autospec=True)
-    def test_introspect_set_ipmi_credentials_disabled(self, introspect_mock):
-        headers = {conf.VERSION_HEADER: '1.9'}
-        res = self.app.post('/v1/introspection/%s?new_ipmi_username=user&'
-                            'new_ipmi_password=password' % self.uuid,
-                            headers=headers)
-        self.assertEqual(400, res.status_code)
-        self.assertFalse(introspect_mock.called)
-
-    @mock.patch.object(introspect, 'introspect', autospec=True)
-    def test_introspect_set_ipmi_credentials_no_user(self, introspect_mock):
-        res = self.app.post('/v1/introspection/%s?'
-                            'new_ipmi_password=password' % self.uuid)
-        self.assertEqual(202, res.status_code)
-        introspect_mock.assert_called_once_with(
-            self.uuid,
-            new_ipmi_credentials=(None, 'password'),
-            token=None)
-
     @mock.patch.object(introspect, 'introspect', autospec=True)
     def test_intospect_failed(self, introspect_mock):
         introspect_mock.side_effect = utils.Error("boom")
@@ -100,7 +67,6 @@ class TestApiIntrospect(BaseAPITest):
             json.loads(res.data.decode('utf-8'))['error']['message'])
         introspect_mock.assert_called_once_with(
             self.uuid,
-            new_ipmi_credentials=None,
             token=None)
 
     @mock.patch.object(utils, 'check_auth', autospec=True)
@@ -193,7 +159,8 @@ class GetStatusAPIBaseTest(BaseAPITest):
             uuid=self.uuid,
             started_at=datetime.datetime(1, 1, 1),
             finished_at=datetime.datetime(1, 1, 2),
-            error='boom')
+            error='boom',
+            state=istate.States.error)
         self.finished_node.links = [
             {u'href': u'http://localhost/v1/introspection/%s' %
              self.finished_node.uuid,
@@ -201,6 +168,7 @@ class GetStatusAPIBaseTest(BaseAPITest):
         ]
         self.finished_node.status = {
             'finished': True,
+            'state': self.finished_node._state,
             'started_at': self.finished_node.started_at.isoformat(),
             'finished_at': self.finished_node.finished_at.isoformat(),
             'error': self.finished_node.error,
@@ -210,7 +178,8 @@ class GetStatusAPIBaseTest(BaseAPITest):
 
         self.unfinished_node = node_cache.NodeInfo(
             uuid=self.uuid2,
-            started_at=datetime.datetime(1, 1, 1))
+            started_at=datetime.datetime(1, 1, 1),
+            state=istate.States.processing)
         self.unfinished_node.links = [
             {u'href': u'http://localhost/v1/introspection/%s' %
              self.unfinished_node.uuid,
@@ -220,6 +189,7 @@ class GetStatusAPIBaseTest(BaseAPITest):
                        if self.unfinished_node.finished_at else None)
         self.unfinished_node.status = {
             'finished': False,
+            'state': self.unfinished_node._state,
             'started_at': self.unfinished_node.started_at.isoformat(),
             'finished_at': finished_at,
             'error': None,
@@ -643,154 +613,3 @@ class TestPlugins(unittest.TestCase):
     def test_manager_is_cached(self):
         self.assertIs(plugins_base.processing_hooks_manager(),
                       plugins_base.processing_hooks_manager())
-
-
-@mock.patch.object(firewall, 'init')
-@mock.patch.object(utils, 'add_auth_middleware')
-@mock.patch.object(ir_utils, 'get_client')
-@mock.patch.object(db, 'init')
-class TestInit(test_base.BaseTest):
-    def setUp(self):
-        super(TestInit, self).setUp()
-        # Tests default to a synchronous executor which can't be used here
-        utils._EXECUTOR = None
-        self.service = main.Service()
-
-    @mock.patch.object(firewall, 'clean_up', lambda: None)
-    def tearDown(self):
-        self.service.shutdown()
-        super(TestInit, self).tearDown()
-
-    def test_ok(self, mock_node_cache, mock_get_client, mock_auth,
-                mock_firewall):
-        CONF.set_override('auth_strategy', 'keystone')
-        self.service.init()
-        mock_auth.assert_called_once_with(main.app)
-        mock_node_cache.assert_called_once_with()
-        mock_firewall.assert_called_once_with()
-
-    def test_init_without_authenticate(self, mock_node_cache, mock_get_client,
-                                       mock_auth, mock_firewall):
-        CONF.set_override('auth_strategy', 'noauth')
-        self.service.init()
-        self.assertFalse(mock_auth.called)
-
-    @mock.patch.object(main.LOG, 'warning')
-    def test_init_with_no_data_storage(self, mock_log, mock_node_cache,
-                                       mock_get_client, mock_auth,
-                                       mock_firewall):
-        msg = ('Introspection data will not be stored. Change '
-               '"[processing] store_data" option if this is not the '
-               'desired behavior')
-        self.service.init()
-        mock_log.assert_called_once_with(msg)
-
-    @mock.patch.object(main.LOG, 'info')
-    def test_init_with_swift_storage(self, mock_log, mock_node_cache,
-                                     mock_get_client, mock_auth,
-                                     mock_firewall):
-        CONF.set_override('store_data', 'swift', 'processing')
-        msg = mock.call('Introspection data will be stored in Swift in the '
-                        'container %s', CONF.swift.container)
-        self.service.init()
-        self.assertIn(msg, mock_log.call_args_list)
-
-    def test_init_without_manage_firewall(self, mock_node_cache,
-                                          mock_get_client, mock_auth,
-                                          mock_firewall):
-        CONF.set_override('manage_firewall', False, 'firewall')
-        self.service.init()
-        self.assertFalse(mock_firewall.called)
-
-    @mock.patch.object(main.LOG, 'critical')
-    def test_init_failed_processing_hook(self, mock_log, mock_node_cache,
-                                         mock_get_client, mock_auth,
-                                         mock_firewall):
-        CONF.set_override('processing_hooks', 'foo!', 'processing')
-        plugins_base._HOOKS_MGR = None
-
-        self.assertRaises(SystemExit, self.service.init)
-        mock_log.assert_called_once_with(mock.ANY, "'foo!'")
-
-
-class TestCreateSSLContext(test_base.BaseTest):
-
-    def test_use_ssl_false(self):
-        CONF.set_override('use_ssl', False)
-        con = main.create_ssl_context()
-        self.assertIsNone(con)
-
-    @mock.patch.object(sys, 'version_info')
-    def test_old_python_returns_none(self, mock_version_info):
-        mock_version_info.__lt__.return_value = True
-        CONF.set_override('use_ssl', True)
-        con = main.create_ssl_context()
-        self.assertIsNone(con)
-
-    @unittest.skipIf(sys.version_info[:3] < (2, 7, 9),
-                     'This feature is unsupported in this version of python '
-                     'so the tests will be skipped')
-    @mock.patch.object(ssl, 'create_default_context', autospec=True)
-    def test_use_ssl_true(self, mock_cdc):
-        CONF.set_override('use_ssl', True)
-        m_con = mock_cdc()
-        con = main.create_ssl_context()
-        self.assertEqual(m_con, con)
-
-    @unittest.skipIf(sys.version_info[:3] < (2, 7, 9),
-                     'This feature is unsupported in this version of python '
-                     'so the tests will be skipped')
-    @mock.patch.object(ssl, 'create_default_context', autospec=True)
-    def test_only_key_path_provided(self, mock_cdc):
-        CONF.set_override('use_ssl', True)
-        CONF.set_override('ssl_key_path', '/some/fake/path')
-        mock_context = mock_cdc()
-        con = main.create_ssl_context()
-        self.assertEqual(mock_context, con)
-        self.assertFalse(mock_context.load_cert_chain.called)
-
-    @unittest.skipIf(sys.version_info[:3] < (2, 7, 9),
-                     'This feature is unsupported in this version of python '
-                     'so the tests will be skipped')
-    @mock.patch.object(ssl, 'create_default_context', autospec=True)
-    def test_only_cert_path_provided(self, mock_cdc):
-        CONF.set_override('use_ssl', True)
-        CONF.set_override('ssl_cert_path', '/some/fake/path')
-        mock_context = mock_cdc()
-        con = main.create_ssl_context()
-        self.assertEqual(mock_context, con)
-        self.assertFalse(mock_context.load_cert_chain.called)
-
-    @unittest.skipIf(sys.version_info[:3] < (2, 7, 9),
-                     'This feature is unsupported in this version of python '
-                     'so the tests will be skipped')
-    @mock.patch.object(ssl, 'create_default_context', autospec=True)
-    def test_both_paths_provided(self, mock_cdc):
-        key_path = '/some/fake/path/key'
-        cert_path = '/some/fake/path/cert'
-        CONF.set_override('use_ssl', True)
-        CONF.set_override('ssl_key_path', key_path)
-        CONF.set_override('ssl_cert_path', cert_path)
-        mock_context = mock_cdc()
-        con = main.create_ssl_context()
-        self.assertEqual(mock_context, con)
-        mock_context.load_cert_chain.assert_called_once_with(cert_path,
-                                                             key_path)
-
-    @unittest.skipIf(sys.version_info[:3] < (2, 7, 9),
-                     'This feature is unsupported in this version of python '
-                     'so the tests will be skipped')
-    @mock.patch.object(ssl, 'create_default_context', autospec=True)
-    def test_load_cert_chain_fails(self, mock_cdc):
-        CONF.set_override('use_ssl', True)
-        key_path = '/some/fake/path/key'
-        cert_path = '/some/fake/path/cert'
-        CONF.set_override('use_ssl', True)
-        CONF.set_override('ssl_key_path', key_path)
-        CONF.set_override('ssl_cert_path', cert_path)
-        mock_context = mock_cdc()
-        mock_context.load_cert_chain.side_effect = IOError('Boom!')
-        con = main.create_ssl_context()
-        self.assertEqual(mock_context, con)
-        mock_context.load_cert_chain.assert_called_once_with(cert_path,
-                                                             key_path)
