@@ -38,7 +38,7 @@ class TestNodeCache(test_base.NodeTest):
     def test_add_node(self):
         # Ensure previous node information is cleared
         uuid2 = uuidutils.generate_uuid()
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Node(uuid=self.node.uuid,
                     state=istate.States.starting).save(session)
@@ -75,7 +75,7 @@ class TestNodeCache(test_base.NodeTest):
                          [(row.name, row.value, row.node_uuid) for row in res])
 
     def test__delete_node(self):
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Node(uuid=self.node.uuid,
                     state=istate.States.finished).save(session)
@@ -88,7 +88,7 @@ class TestNodeCache(test_base.NodeTest):
                 session)
 
         node_cache._delete_node(self.uuid)
-        session = db.get_session()
+        session = db.get_writer_session()
         row_node = db.model_query(db.Node).filter_by(
             uuid=self.uuid).first()
         self.assertIsNone(row_node)
@@ -108,7 +108,7 @@ class TestNodeCache(test_base.NodeTest):
         uuid2 = uuidutils.generate_uuid()
         uuids = {self.uuid}
         mock__list_node_uuids.return_value = {self.uuid, uuid2}
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             node_cache.delete_nodes_not_in_list(uuids)
         mock__delete_node.assert_called_once_with(uuid2)
@@ -116,7 +116,7 @@ class TestNodeCache(test_base.NodeTest):
         mock__get_lock_ctx.return_value.__enter__.assert_called_once_with()
 
     def test_active_macs(self):
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Node(uuid=self.node.uuid,
                     state=istate.States.starting).save(session)
@@ -129,7 +129,7 @@ class TestNodeCache(test_base.NodeTest):
                          node_cache.active_macs())
 
     def test__list_node_uuids(self):
-        session = db.get_session()
+        session = db.get_writer_session()
         uuid2 = uuidutils.generate_uuid()
         with session.begin():
             db.Node(uuid=self.node.uuid,
@@ -141,7 +141,7 @@ class TestNodeCache(test_base.NodeTest):
         self.assertEqual({self.uuid, uuid2}, node_uuid_list)
 
     def test_add_attribute(self):
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Node(uuid=self.node.uuid,
                     state=istate.States.starting).save(session)
@@ -158,7 +158,7 @@ class TestNodeCache(test_base.NodeTest):
         self.assertEqual({'key': ['value']}, node_info.attributes)
 
     def test_add_attribute_same_name(self):
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Node(uuid=self.node.uuid,
                     state=istate.States.starting).save(session)
@@ -175,7 +175,7 @@ class TestNodeCache(test_base.NodeTest):
                          [tuple(row) for row in res])
 
     def test_add_attribute_same_value(self):
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Node(uuid=self.node.uuid,
                     state=istate.States.starting).save(session)
@@ -198,7 +198,7 @@ class TestNodeCache(test_base.NodeTest):
                           'mac': self.macs},
                          node_info.attributes)
         # check invalidation
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Attribute(uuid=uuidutils.generate_uuid(), name='foo',
                          value='bar', node_uuid=self.uuid).save(session)
@@ -285,7 +285,7 @@ class TestNodeCacheFind(test_base.NodeTest):
         self.assertTrue(res._locked)
 
     def test_inconsistency(self):
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             (db.model_query(db.Node).filter_by(uuid=self.uuid).
                 delete())
@@ -293,7 +293,7 @@ class TestNodeCacheFind(test_base.NodeTest):
                           bmc_address='1.2.3.4')
 
     def test_already_finished(self):
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             (db.model_query(db.Node).filter_by(uuid=self.uuid).
                 update({'finished_at': datetime.datetime.utcnow()}))
@@ -305,7 +305,7 @@ class TestNodeCacheCleanUp(test_base.NodeTest):
     def setUp(self):
         super(TestNodeCacheCleanUp, self).setUp()
         self.started_at = datetime.datetime.utcnow()
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Node(uuid=self.uuid,
                     state=istate.States.waiting,
@@ -350,7 +350,7 @@ class TestNodeCacheCleanUp(test_base.NodeTest):
     def test_timeout(self, time_mock, get_lock_mock):
         # Add a finished node to confirm we don't try to timeout it
         time_mock.return_value = self.started_at
-        session = db.get_session()
+        session = db.get_writer_session()
         finished_at = self.started_at + datetime.timedelta(seconds=60)
         with session.begin():
             db.Node(uuid=self.uuid + '1', started_at=self.started_at,
@@ -376,9 +376,31 @@ class TestNodeCacheCleanUp(test_base.NodeTest):
         get_lock_mock.assert_called_once_with(self.uuid)
         get_lock_mock.return_value.acquire.assert_called_once_with()
 
+    @mock.patch.object(node_cache, '_get_lock', autospec=True)
+    @mock.patch.object(timeutils, 'utcnow')
+    def test_timeout_active_state(self, time_mock, get_lock_mock):
+        time_mock.return_value = self.started_at
+        session = db.get_writer_session()
+        CONF.set_override('timeout', 1)
+        for state in [istate.States.starting, istate.States.enrolling,
+                      istate.States.processing, istate.States.reapplying]:
+            db.model_query(db.Node, session=session).filter_by(
+                uuid=self.uuid).update({'state': state, 'finished_at': None})
+
+            current_time = self.started_at + datetime.timedelta(seconds=2)
+            time_mock.return_value = current_time
+
+            self.assertEqual([self.uuid], node_cache.clean_up())
+
+            res = [(row.state, row.finished_at, row.error) for row in
+                   db.model_query(db.Node).all()]
+            self.assertEqual(
+                [(istate.States.error, current_time, 'Introspection timeout')],
+                res)
+
     def test_old_status(self):
         CONF.set_override('node_status_keep_time', 42)
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.model_query(db.Node).update(
                 {'finished_at': (datetime.datetime.utcnow() -
@@ -388,12 +410,24 @@ class TestNodeCacheCleanUp(test_base.NodeTest):
 
         self.assertEqual([], db.model_query(db.Node).all())
 
+    def test_old_status_disabled(self):
+        # Status clean up is disabled by default
+        session = db.get_writer_session()
+        with session.begin():
+            db.model_query(db.Node).update(
+                {'finished_at': (datetime.datetime.utcnow() -
+                                 datetime.timedelta(days=10000))})
+
+        self.assertEqual([], node_cache.clean_up())
+
+        self.assertNotEqual([], db.model_query(db.Node).all())
+
 
 class TestNodeCacheGetNode(test_base.NodeTest):
     def test_ok(self):
         started_at = (datetime.datetime.utcnow() -
                       datetime.timedelta(seconds=42))
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Node(uuid=self.uuid,
                     state=istate.States.starting,
@@ -409,7 +443,7 @@ class TestNodeCacheGetNode(test_base.NodeTest):
     def test_locked(self):
         started_at = (datetime.datetime.utcnow() -
                       datetime.timedelta(seconds=42))
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Node(uuid=self.uuid,
                     state=istate.States.starting,
@@ -429,7 +463,7 @@ class TestNodeCacheGetNode(test_base.NodeTest):
     def test_with_name(self):
         started_at = (datetime.datetime.utcnow() -
                       datetime.timedelta(seconds=42))
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Node(uuid=self.uuid,
                     state=istate.States.starting,
@@ -457,7 +491,7 @@ class TestNodeInfoFinished(test_base.NodeTest):
                             mac=self.macs)
         self.node_info = node_cache.NodeInfo(
             uuid=self.uuid, started_at=datetime.datetime(3, 1, 4))
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Option(uuid=self.uuid, name='foo', value='bar').save(
                 session)
@@ -465,7 +499,7 @@ class TestNodeInfoFinished(test_base.NodeTest):
     def test_success(self):
         self.node_info.finished()
 
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             self.assertEqual((datetime.datetime(1, 1, 1), None),
                              tuple(db.model_query(
@@ -499,7 +533,7 @@ class TestNodeInfoOptions(test_base.NodeTest):
                             bmc_address='1.2.3.4',
                             mac=self.macs)
         self.node_info = node_cache.NodeInfo(uuid=self.uuid, started_at=3.14)
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Option(uuid=self.uuid, name='foo', value='"bar"').save(
                 session)
@@ -579,7 +613,7 @@ class TestNodeCacheIronicObjects(unittest.TestCase):
 
         mock_ironic.assert_called_once_with()
         mock_ironic.return_value.node.list_ports.assert_called_once_with(
-            self.uuid, limit=0)
+            self.uuid, limit=0, detail=True)
 
     def test_ports_ironic_preset(self, mock_ironic):
         mock_ironic2 = mock.Mock()
@@ -591,7 +625,7 @@ class TestNodeCacheIronicObjects(unittest.TestCase):
 
         self.assertFalse(mock_ironic.called)
         mock_ironic2.node.list_ports.assert_called_once_with(
-            self.uuid, limit=0)
+            self.uuid, limit=0, detail=True)
 
 
 class TestUpdate(test_base.NodeTest):
@@ -721,6 +755,71 @@ class TestUpdate(test_base.NodeTest):
         self.ironic.port.delete.assert_called_once_with('0')
         self.assertEqual(['mac1'], list(self.node_info.ports()))
 
+    @mock.patch.object(node_cache.LOG, 'warning', autospec=True)
+    def test_create_ports(self, mock_warn):
+        ports = [
+            'mac2',
+            {'mac': 'mac3', 'client_id': '42', 'pxe': False},
+            {'mac': 'mac4', 'pxe': True}
+        ]
+
+        self.node_info.create_ports(ports)
+        self.assertEqual({'mac0', 'mac1', 'mac2', 'mac3', 'mac4'},
+                         set(self.node_info.ports()))
+
+        create_calls = [
+            mock.call(node_uuid=self.uuid, address='mac2', extra={},
+                      pxe_enabled=True),
+            mock.call(node_uuid=self.uuid, address='mac3',
+                      extra={'client-id': '42'}, pxe_enabled=False),
+            mock.call(node_uuid=self.uuid, address='mac4', extra={},
+                      pxe_enabled=True),
+        ]
+        self.assertEqual(create_calls, self.ironic.port.create.call_args_list)
+        # No conflicts - cache was not cleared - no calls to port.list
+        self.assertFalse(mock_warn.called)
+        self.assertFalse(self.ironic.port.list.called)
+
+    @mock.patch.object(node_cache.LOG, 'info', autospec=True)
+    def test__create_port(self, mock_info):
+        uuid = uuidutils.generate_uuid()
+        address = 'mac1'
+        self.ironic.port.create.return_value = mock.Mock(uuid=uuid,
+                                                         address=address)
+
+        self.node_info._create_port(address, client_id='42')
+
+        self.ironic.port.create.assert_called_once_with(
+            node_uuid=self.uuid, address='mac1', client_id='42')
+        mock_info.assert_called_once_with(
+            mock.ANY, {'uuid': uuid, 'mac': address,
+                       'attrs': {'client_id': '42'}},
+            node_info=self.node_info)
+
+    @mock.patch.object(node_cache.LOG, 'warning', autospec=True)
+    def test_create_ports_with_conflicts(self, mock_warn):
+        self.ironic.port.create.return_value = mock.Mock(
+            uuid='fake', address='mac')
+
+        ports = [
+            'mac',
+            {'mac': 'mac0'},
+            'mac1',
+            {'mac': 'mac2', 'client_id': '42', 'pxe': False},
+        ]
+
+        self.node_info.create_ports(ports)
+
+        create_calls = [
+            mock.call(node_uuid=self.uuid, address='mac', extra={},
+                      pxe_enabled=True),
+            mock.call(node_uuid=self.uuid, address='mac2',
+                      extra={'client-id': '42'}, pxe_enabled=False),
+        ]
+        self.assertEqual(create_calls, self.ironic.port.create.call_args_list)
+        mock_warn.assert_called_once_with(mock.ANY, ['mac0', 'mac1'],
+                                          node_info=self.node_info)
+
 
 class TestNodeCacheGetByPath(test_base.NodeTest):
     def setUp(self):
@@ -828,7 +927,7 @@ class TestNodeCacheListNode(test_base.NodeTest):
     def setUp(self):
         super(TestNodeCacheListNode, self).setUp()
         self.uuid2 = uuidutils.generate_uuid()
-        session = db.get_session()
+        session = db.get_writer_session()
         with session.begin():
             db.Node(uuid=self.uuid,
                     started_at=datetime.datetime(1, 1, 2)).save(session)
