@@ -96,31 +96,18 @@ class TestSchedulerHook(test_base.NodeTest):
         self.assertCalledWithPatch(patch, mock_patch)
 
 
-class TestValidateInterfacesHook(test_base.NodeTest):
-    def setUp(self):
-        super(TestValidateInterfacesHook, self).setUp()
-        self.hook = std_plugins.ValidateInterfacesHook()
-        self.existing_ports = [mock.Mock(spec=['address', 'uuid'],
-                                         address=a)
-                               for a in (self.macs[1],
-                                         '44:44:44:44:44:44')]
-        self.node_info = node_cache.NodeInfo(uuid=self.uuid, started_at=0,
-                                             node=self.node,
-                                             ports=self.existing_ports)
-
+class TestValidateInterfacesHookLoad(test_base.NodeTest):
     def test_hook_loadable_by_name(self):
         CONF.set_override('processing_hooks', 'validate_interfaces',
                           'processing')
         ext = base.processing_hooks_manager()['validate_interfaces']
         self.assertIsInstance(ext.obj, std_plugins.ValidateInterfacesHook)
 
-    def test_wrong_add_ports(self):
-        CONF.set_override('add_ports', 'foobar', 'processing')
-        self.assertRaises(SystemExit, std_plugins.ValidateInterfacesHook)
 
-    def test_wrong_keep_ports(self):
-        CONF.set_override('keep_ports', 'foobar', 'processing')
-        self.assertRaises(SystemExit, std_plugins.ValidateInterfacesHook)
+class TestValidateInterfacesHookBeforeProcessing(test_base.NodeTest):
+    def setUp(self):
+        super(TestValidateInterfacesHookBeforeProcessing, self).setUp()
+        self.hook = std_plugins.ValidateInterfacesHook()
 
     def test_no_interfaces(self):
         self.assertRaisesRegex(utils.Error,
@@ -157,6 +144,8 @@ class TestValidateInterfacesHook(test_base.NodeTest):
     def test_only_pxe_no_boot_interface(self):
         del self.data['boot_interface']
         self.hook.before_processing(self.data)
+        self.active_interfaces[self.pxe_iface_name]['pxe'] = False
+        self.all_interfaces[self.pxe_iface_name]['pxe'] = False
 
         self.assertEqual(self.active_interfaces, self.data['interfaces'])
         self.assertEqual(sorted(i['mac'] for i in
@@ -184,6 +173,24 @@ class TestValidateInterfacesHook(test_base.NodeTest):
                          sorted(self.data['macs']))
         self.assertEqual(self.all_interfaces, self.data['all_interfaces'])
 
+    @mock.patch.object(node_cache.NodeInfo, 'create_ports')
+    def test_disabled_bad_conf(self, mock_create_port):
+        CONF.set_override('add_ports', 'disabled', 'processing')
+        CONF.set_override('keep_ports', 'added', 'processing')
+
+        self.assertRaisesRegex(utils.Error, 'Configuration error:',
+                               self.hook.__init__)
+        mock_create_port.assert_not_called()
+
+    @mock.patch.object(node_cache.NodeInfo, 'create_ports')
+    def test_disabled(self, mock_create_port):
+        CONF.set_override('add_ports', 'disabled', 'processing')
+        CONF.set_override('keep_ports', 'all', 'processing')
+
+        self.hook.before_processing(self.data)
+        self.assertEqual(self.active_interfaces, self.data['interfaces'])
+        mock_create_port.assert_not_called()
+
     def test_malformed_interfaces(self):
         self.inventory['interfaces'] = [
             # no name
@@ -212,27 +219,95 @@ class TestValidateInterfacesHook(test_base.NodeTest):
         self.assertRaisesRegex(utils.Error, 'No suitable interfaces found',
                                self.hook.before_processing, self.data)
 
-    @mock.patch.object(node_cache.NodeInfo, 'delete_port', autospec=True)
-    def test_keep_all(self, mock_delete_port):
+
+@mock.patch.object(node_cache.NodeInfo, 'delete_port', autospec=True)
+@mock.patch.object(node_cache.NodeInfo, 'create_ports', autospec=True)
+class TestValidateInterfacesHookBeforeUpdateDeletion(test_base.NodeTest):
+    def setUp(self):
+        super(TestValidateInterfacesHookBeforeUpdateDeletion, self).setUp()
+        self.hook = std_plugins.ValidateInterfacesHook()
+        self.interfaces_to_create = sorted(self.valid_interfaces.values(),
+                                           key=lambda i: i['mac'])
+        self.existing_ports = [mock.Mock(spec=['address', 'uuid'],
+                                         address=a)
+                               for a in (self.macs[1],
+                                         '44:44:44:44:44:44')]
+        self.node_info = node_cache.NodeInfo(uuid=self.uuid, started_at=0,
+                                             node=self.node,
+                                             ports=self.existing_ports)
+
+    def test_keep_all(self, mock_create_ports, mock_delete_port):
         self.hook.before_update(self.data, self.node_info)
+
+        # NOTE(dtantsur): dictionary ordering is not defined
+        mock_create_ports.assert_called_once_with(self.node_info, mock.ANY)
+        self.assertEqual(self.interfaces_to_create,
+                         sorted(mock_create_ports.call_args[0][1],
+                                key=lambda i: i['mac']))
+
         self.assertFalse(mock_delete_port.called)
 
-    @mock.patch.object(node_cache.NodeInfo, 'delete_port')
-    def test_keep_present(self, mock_delete_port):
+    def test_keep_present(self, mock_create_ports, mock_delete_port):
         CONF.set_override('keep_ports', 'present', 'processing')
         self.data['all_interfaces'] = self.all_interfaces
         self.hook.before_update(self.data, self.node_info)
 
-        mock_delete_port.assert_called_once_with(self.existing_ports[1])
+        mock_create_ports.assert_called_once_with(self.node_info, mock.ANY)
+        self.assertEqual(self.interfaces_to_create,
+                         sorted(mock_create_ports.call_args[0][1],
+                                key=lambda i: i['mac']))
 
-    @mock.patch.object(node_cache.NodeInfo, 'delete_port')
-    def test_keep_added(self, mock_delete_port):
+        mock_delete_port.assert_called_once_with(self.node_info,
+                                                 self.existing_ports[1])
+
+    def test_keep_added(self, mock_create_ports, mock_delete_port):
         CONF.set_override('keep_ports', 'added', 'processing')
         self.data['macs'] = [self.pxe_mac]
         self.hook.before_update(self.data, self.node_info)
 
-        mock_delete_port.assert_any_call(self.existing_ports[0])
-        mock_delete_port.assert_any_call(self.existing_ports[1])
+        mock_create_ports.assert_called_once_with(self.node_info, mock.ANY)
+        self.assertEqual(self.interfaces_to_create,
+                         sorted(mock_create_ports.call_args[0][1],
+                                key=lambda i: i['mac']))
+
+        mock_delete_port.assert_any_call(self.node_info,
+                                         self.existing_ports[0])
+        mock_delete_port.assert_any_call(self.node_info,
+                                         self.existing_ports[1])
+
+
+@mock.patch.object(node_cache.NodeInfo, 'patch_port', autospec=True)
+@mock.patch.object(node_cache.NodeInfo, 'create_ports', autospec=True)
+class TestValidateInterfacesHookBeforeUpdatePXEEnabled(test_base.NodeTest):
+    def setUp(self):
+        super(TestValidateInterfacesHookBeforeUpdatePXEEnabled, self).setUp()
+        self.hook = std_plugins.ValidateInterfacesHook()
+        # Note(milan) assumes the ordering of self.macs from test_base.NodeTest
+        # where the first item '11:22:33:44:55:66' is the MAC of the
+        # self.pxe_iface_name 'eth1', the "real" PXE interface
+        sorted_interfaces = sorted(self.valid_interfaces.values(),
+                                   key=lambda i: i['mac'])
+        self.existing_ports = [
+            mock.Mock(spec=['address', 'uuid', 'pxe_enabled'],
+                      address=iface['mac'], pxe_enabled=True)
+            for iface in sorted_interfaces
+        ]
+        self.node_info = node_cache.NodeInfo(uuid=self.uuid, started_at=0,
+                                             node=self.node,
+                                             ports=self.existing_ports)
+
+    def test_fix_pxe_enabled(self, mock_create_ports, mock_patch_port):
+        self.hook.before_update(self.data, self.node_info)
+        # Note(milan) there are just 2 self.valid_interfaces, 'eth1' and 'ib0'
+        # eth1 is the PXE booting interface and eth1.mac < ib0.mac
+        mock_patch_port.assert_called_once_with(
+            self.node_info, self.existing_ports[1],
+            [{'op': 'replace', 'path': '/pxe_enabled', 'value': False}])
+
+    def test_no_overwrite(self, mock_create_ports, mock_patch_port):
+        CONF.set_override('overwrite_existing', False, 'processing')
+        self.hook.before_update(self.data, self.node_info)
+        self.assertFalse(mock_patch_port.called)
 
 
 class TestRootDiskSelection(test_base.NodeTest):
