@@ -101,6 +101,17 @@ class TestProcess(BaseProcessTest):
         self.process_mock.assert_called_once_with(self.node_info, self.node,
                                                   self.data)
 
+    def test_ipmi_not_detected(self):
+        self.inventory['bmc_address'] = '0.0.0.0'
+        process.process(self.data)
+
+        self.find_mock.assert_called_once_with(bmc_address=None, mac=mock.ANY)
+        actual_macs = self.find_mock.call_args[1]['mac']
+        self.assertEqual(sorted(self.all_macs), sorted(actual_macs))
+        self.cli.node.get.assert_called_once_with(self.uuid)
+        self.process_mock.assert_called_once_with(self.node_info, self.node,
+                                                  self.data)
+
     def test_not_found_in_cache(self):
         self.find_mock.side_effect = utils.Error('not found')
         self.assertRaisesRegex(utils.Error,
@@ -348,19 +359,11 @@ class TestProcessNode(BaseTest):
         self.validate_attempts = 5
         self.data['macs'] = self.macs  # validate_interfaces hook
         self.valid_interfaces['eth3'] = {
-            'mac': self.macs[1], 'ip': self.ips[1], 'extra': {}
+            'mac': self.macs[1], 'ip': self.ips[1], 'extra': {}, 'pxe': False
         }
         self.data['interfaces'] = self.valid_interfaces
         self.ports = self.all_ports
 
-        self.new_creds = ('user', 'password')
-        self.patch_credentials = [
-            {'op': 'add', 'path': '/driver_info/ipmi_username',
-             'value': self.new_creds[0]},
-            {'op': 'add', 'path': '/driver_info/ipmi_password',
-             'value': self.new_creds[1]},
-        ]
-
         self.cli.node.get_boot_device.side_effect = (
             [RuntimeError()] * self.validate_attempts + [None])
         self.cli.port.create.side_effect = self.ports
@@ -382,12 +385,6 @@ class TestProcessNode(BaseTest):
         ret_val = process._process_node(self.node_info, self.node, self.data)
         self.assertEqual(self.uuid, ret_val.get('uuid'))
 
-    def test_return_includes_uuid_with_ipmi_creds(self):
-        self.node_info.set_option('new_ipmi_credentials', self.new_creds)
-        ret_val = process._process_node(self.node_info, self.node, self.data)
-        self.assertEqual(self.uuid, ret_val.get('uuid'))
-        self.assertTrue(ret_val.get('ipmi_setup_credentials'))
-
     @mock.patch.object(example_plugin.ExampleProcessingHook, 'before_update')
     def test_wrong_provision_state(self, post_hook_mock):
         self.node.provision_state = 'active'
@@ -403,10 +400,12 @@ class TestProcessNode(BaseTest):
 
         self.cli.port.create.assert_any_call(node_uuid=self.uuid,
                                              address=self.macs[0],
-                                             extra={})
+                                             extra={},
+                                             pxe_enabled=True)
         self.cli.port.create.assert_any_call(node_uuid=self.uuid,
                                              address=self.macs[1],
-                                             extra={})
+                                             extra={},
+                                             pxe_enabled=False)
         self.cli.node.set_power_state.assert_called_once_with(self.uuid, 'off')
         self.assertFalse(self.cli.node.validate.called)
 
@@ -421,53 +420,10 @@ class TestProcessNode(BaseTest):
 
         self.cli.port.create.assert_any_call(node_uuid=self.uuid,
                                              address=self.macs[0],
-                                             extra={})
+                                             extra={}, pxe_enabled=True)
         self.cli.port.create.assert_any_call(node_uuid=self.uuid,
                                              address=self.macs[1],
-                                             extra={})
-
-    def test_set_ipmi_credentials(self):
-        self.node_info.set_option('new_ipmi_credentials', self.new_creds)
-
-        process._process_node(self.node_info, self.node, self.data)
-
-        self.cli.node.update.assert_any_call(self.uuid, self.patch_credentials)
-        self.cli.node.set_power_state.assert_called_once_with(self.uuid, 'off')
-        self.cli.node.get_boot_device.assert_called_with(self.uuid)
-        self.assertEqual(self.validate_attempts + 1,
-                         self.cli.node.get_boot_device.call_count)
-
-    def test_set_ipmi_credentials_no_address(self):
-        self.node_info.set_option('new_ipmi_credentials', self.new_creds)
-        del self.node.driver_info['ipmi_address']
-        self.patch_credentials.append({'op': 'add',
-                                       'path': '/driver_info/ipmi_address',
-                                       'value': self.bmc_address})
-
-        process._process_node(self.node_info, self.node, self.data)
-
-        self.cli.node.update.assert_any_call(self.uuid, self.patch_credentials)
-        self.cli.node.set_power_state.assert_called_once_with(self.uuid, 'off')
-        self.cli.node.get_boot_device.assert_called_with(self.uuid)
-        self.assertEqual(self.validate_attempts + 1,
-                         self.cli.node.get_boot_device.call_count)
-
-    @mock.patch.object(node_cache.NodeInfo, 'finished', autospec=True)
-    def test_set_ipmi_credentials_timeout(self, finished_mock):
-        self.node_info.set_option('new_ipmi_credentials', self.new_creds)
-        self.cli.node.get_boot_device.side_effect = RuntimeError('boom')
-
-        process._process_node(self.node_info, self.node, self.data)
-
-        self.cli.node.update.assert_any_call(self.uuid, self.patch_credentials)
-        self.assertEqual(2, self.cli.node.update.call_count)
-        self.assertEqual(process._CREDENTIALS_WAIT_RETRIES,
-                         self.cli.node.get_boot_device.call_count)
-        self.assertFalse(self.cli.node.set_power_state.called)
-        finished_mock.assert_called_once_with(
-            mock.ANY,
-            error='Failed to validate updated IPMI credentials for node %s, '
-            'node might require maintenance' % self.uuid)
+                                             extra={}, pxe_enabled=False)
 
     @mock.patch.object(node_cache.NodeInfo, 'finished', autospec=True)
     def test_power_off_failed(self, finished_mock):
@@ -607,7 +563,6 @@ class TestReapplyNode(BaseTest):
                                              started_at=self.started_at,
                                              node=self.node)
         self.node_info.invalidate_cache = mock.Mock()
-        self.new_creds = ('user', 'password')
 
         self.cli.port.create.side_effect = self.ports
         self.cli.node.update.return_value = self.node
@@ -667,7 +622,8 @@ class TestReapplyNode(BaseTest):
         self.cli.port.create.assert_called_once_with(
             node_uuid=self.uuid,
             address=swifted_data['macs'][0],
-            extra={}
+            extra={},
+            pxe_enabled=True
         )
 
     @prepare_mocks
