@@ -32,9 +32,15 @@ _EXECUTOR = None
 
 def get_ipmi_address_from_data(introspection_data):
     try:
-        return introspection_data['inventory']['bmc_address']
+        result = introspection_data['inventory']['bmc_address']
     except KeyError:
-        return introspection_data.get('ipmi_address')
+        result = introspection_data.get('ipmi_address')
+
+    if result in ('', '0.0.0.0'):
+        # ipmitool can return these values, if it does not know the address
+        return None
+    else:
+        return result
 
 
 def get_pxe_mac(introspection_data):
@@ -72,10 +78,9 @@ def processing_logger_prefix(data=None, node_info=None):
     if pxe_mac:
         parts.append('MAC %s' % pxe_mac)
 
-    if CONF.processing.log_bmc_address:
-        bmc_address = get_ipmi_address_from_data(data) if data else None
-        if bmc_address:
-            parts.append('BMC %s' % bmc_address)
+    bmc_address = get_ipmi_address_from_data(data) if data else None
+    if bmc_address:
+        parts.append('BMC %s' % bmc_address)
 
     if parts:
         return _('[node: %s]') % ' '.join(parts)
